import React, { useContext } from "react"
import { App, Button, Form, Input } from "antd"
import { LockOutlined, QrcodeOutlined, UserOutlined } from "@ant-design/icons"
import { isMobile } from "../../utils"
import CodeInput from "../../components/codeInput"
import { resetPwdApi } from "../../api"
import { useAjax } from "../../hooks/useAjax"
import { DispatchContext } from "../../App"

/**
 * 找回密码
 * @returns 
 */
const PwdPop: React.FC = () => {

    /**************************/
    const { dispatch, state: { initData: { h5LoginLogo: logo } } } = useContext(DispatchContext)!;
    const [form] = Form.useForm()
    const mobile = Form.useWatch('mobile', form)
    const { message } = App.useApp();
    const resetPwd = useAjax((params) => resetPwdApi(params))
    /**************************/

    const onFinish = (values: any) => {
        console.log('Success:', values);
        delete values?.passwordag
        resetPwd.run(values).then(res => {
            if (+res.code === 200) {
                message.success(res.msg || '重置密码成功')
                dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'USER_LOGIN' } })
            } else {
                message.error(res.msg)
            }
        })
    };


    return <div className="pop">
        <div className="pop_body">
            <div className="login_head">
                <img className="login_logo" src={logo} />
                <span className="login_title">找回密码</span>
            </div>
            <div className="login_body">
                <Form
                    name="basic"
                    form={form}
                    onFinish={onFinish}
                >
                    <Form.Item name="username" style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入账号!' }]}>
                        <Input prefix={<UserOutlined />} placeholder="请输入账号" size="large" />
                    </Form.Item>
                    <Form.Item name="mobile" style={{ marginBottom: 10 }} rules={[
                        {
                            required: true,
                            validator(_rule, value) {
                                if (!value) {
                                    return Promise.reject(new Error('请输入手机号!'))
                                } else if (!isMobile(value)) {
                                    return Promise.reject(new Error('请输入正确的手机号!'))
                                }
                                return Promise.resolve()
                            }
                        }
                    ]}>
                        <Input prefix={<UserOutlined />} placeholder="请输入手机号" size="large" />
                    </Form.Item>
                    <Form.Item name="code" style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入验证码!' }]}>
                        <CodeInput mobile={mobile} msgType={4} prefix={<QrcodeOutlined />} placeholder="请输入验证码" size="large" />
                    </Form.Item>
                    <Form.Item name="password" hasFeedback style={{ marginBottom: 10 }} rules={[{ required: true, message: '请输入密码!' }]}>
                        <Input.Password prefix={<LockOutlined />} placeholder="请输入密码" size="large" />
                    </Form.Item>
                    <Form.Item name="passwordag" hasFeedback dependencies={['password']} style={{ marginBottom: 20 }} rules={[
                        { required: true, message: '请再次输入密码!' },
                        ({ getFieldValue }) => ({
                            validator(_, value) {
                                if (!value || getFieldValue('password') === value) {
                                    return Promise.resolve();
                                }
                                return Promise.reject(new Error('两次输入密码不一致!'));
                            },
                        })
                    ]}>
                        <Input.Password prefix={<LockOutlined />} placeholder="请再次输入密码" size="large" />
                    </Form.Item>
                    <Form.Item style={{ marginBottom: 10 }}>
                        <Button type="primary" className="form_button" loading={resetPwd.loading} htmlType="submit" size="large">确定</Button>
                    </Form.Item>
                </Form>
            </div>
            <div className="login_foot" style={{ justifyContent: 'space-between' }}>
                <Button type="text" style={{ padding: 0 }} onClick={() => dispatch({ type: 'setTypeSwitch', params: { typeSwitch: 'USER_LOGIN' } })}>返回登录</Button>
            </div>
        </div>
    </div>
}

export default React.memo(PwdPop)